@@ -17,7 +17,7 @@ morethanoneyear = class(popdata)=="list"
 #if s() is in formula, use GAM
 useGam <- length(grep("s\\(",formula))>0
 if(useGam) {
-  modelFittingFunction = gam
+  modelFittingFunction = mgcv::gam
 } else {
   modelFittingFunction = glm
 }
